@@ -203,11 +203,16 @@ extern int optind;
 #define SUPPORTED
 #include <linux/ext2_fs.h>
 #define HAVE_EXT2FS
+#define HAVE_DTIME
+#if (_FILE_OFFSET_BITS == 64)
+#define LSEEK		lseek
+#define OFF_T		off_t
+#else
 #define USE_MYLSEEK
 #define HAVE_LLSEEK
-#define HAVE_DTIME
 #define LSEEK		mylseek
 #define OFF_T		long long
+#endif
 #define STRTOUL		strtoul
 #define DADDR_T		__u32
 #define EXT2FS_TYPE	"ext2fs"
